from setuptools import setup

setup(name='special_distributions',
      version='1.2',
      description='special_distributions',
      author = 'Mohamed Osama',
      packages=['special_distributions'],
      zip_safe=False)
